{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "pdnnode.name" -}}
{{- include "common.names.name" . -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "pdnnode.fullname" -}}
{{- include "common.names.fullname" . -}}
{{- end -}}

{{/*
Return the proper pdnnode image name
*/}}
{{- define "pdnnode.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.image "global" .Values.global "appVer" .Chart.AppVersion) }}
{{- end -}}

{{/*
Return the proper image name (for the init container volume-permissions image)
*/}}
{{- define "pdnnode.initContainers.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.initContainers.image "global" .Values.global) }}
{{- end -}}

{{/*
Return the proper Docker Image Registry Secret Names
*/}}
{{- define "pdnnode.imagePullSecrets" -}}
{{ include "common.images.pullSecrets" (dict "images" (list .Values.image .Values.initContainers.image) "global" .Values.global) }}
{{- end -}}

{{/*
Return podAnnotations
*/}}
{{- define "pdnnode.podAnnotations" -}}
{{- if .Values.podAnnotations }}
{{ include "common.tplvalues.render" (dict "value" .Values.podAnnotations "context" $) }}
{{- end }}
{{- if and .Values.metrics.enabled .Values.metrics.podAnnotations }}
{{ include "common.tplvalues.render" (dict "value" .Values.metrics.podAnnotations "context" $) }}
{{- end }}
{{- end -}}

{{/*
 Create the name of the service account to use
 */}}
{{- define "pdnnode.serviceAccountName" -}}
{{- if .Values.serviceAccount.create -}}
    {{ default (include "pdnnode.fullname" .) .Values.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Resolve pdnNodeJoinKey value
*/}}
{{- define "pdnnode.pdnNodeJoinKey" -}}
{{- if .Values.global.pdnNodeJoinKey -}}
{{- .Values.global.pdnNodeJoinKey -}}
{{- else if .Values.pdnNodeJoinKey -}}
{{- .Values.pdnNodeJoinKey -}}
{{- end -}}
{{- end -}}

{{/*
Resolve pdnNodeJoinKeySecretName value
*/}}
{{- define "pdnnode.pdnNodeJoinKeySecretName" -}}
{{- if .Values.global.pdnNodeJoinKeySecretName -}}
{{- .Values.global.pdnNodeJoinKeySecretName -}}
{{- else if .Values.pdnNodeJoinKeySecretName -}}
{{- .Values.pdnNodeJoinKeySecretName -}}
{{- else -}}
{{ include "pdnnode.fullname" . }}
{{- end -}}
{{- end -}}

{{/*
Resolve pdnServerUrl value
*/}}
{{- define "pdnnode.pdnServerUrl" -}}
{{- if .Values.global.pdnServerUrl -}}
{{- .Values.global.pdnServerUrl -}}
{{- else if .Values.pdnServerUrl -}}
{{- .Values.pdnServerUrl -}}
{{- end -}}
{{- end -}}

{{/*
Resolve pdnServerInitialConnectionUrl value
*/}}
{{- define "pdnnode.pdnServerInitialConnectionUrl" -}}
{{- if .Values.global.pdnServerInitialConnectionUrl -}}
{{- .Values.global.pdnServerInitialConnectionUrl -}}
{{- else if .Values.pdnServerInitialConnectionUrl -}}
{{- .Values.pdnServerInitialConnectionUrl -}}
{{- end -}}
{{- end -}}

{{/*
Custom certificate copy command
*/}}
{{- define "pdnnode.copyCustomCerts" -}}
echo "Copy custom certificates to {{ .Values.persistence.mountPath }}/etc/security/keys/trusted";
mkdir -p {{ .Values.persistence.mountPath }}/etc/security/keys/trusted;

for file in $(ls -1 /tmp/certs/* | grep -v .key | grep -v ":" | grep -v grep);
do
    if [ -f "${file}" ]; then cp -v ${file} {{ .Values.persistence.mountPath }}/etc/security/keys/trusted
fi
done
{{- end -}}

{{- define "pdnnode.customCertificatesEnabled" -}}
{{- if .Values.customCertificates | default false -}}
{{- if .Values.customCertificates.enabled | default false -}}
{{- .Values.customCertificates.enabled -}}
{{- end -}}
{{- else -}}
{{- .Values.global.customCertificates.enabled -}}
{{- end -}}
{{- end -}}
